# Inference

## Current Approaches

Underlying all of our timeline models is a probabilistic density. In order to do anything of interest, we have to be able to perform inference in this space. The catch is that unlike with simpler models, the integral representing our density is intractable.

In general, the way this is handled in nonparametric Bayesian models can largely be divided into two camps. These are sampling and expectation-maximisation (EM) approaches:
1. The first solution makes use of the fact that while intergrating over the whole measure space is difficult, plugging in values and retrieving an (un-normalised) probability is not. We can exploit this property by performing an intelligent random walk over the surface of the density. The idea is that if we walk for long enough, we'll obtain a reasonable representation of the surface. This is the basis for a family of inference methods called Markov-Chain Monte-Carlo (MCMC) sampling.
2. In broad strokes, the second this method defines a family of densities. The family should be capable of approximating the generating distribution of any given dataset. An iterative optimisation process then occurs to find the distribution in this family that best matches our data.


All current Bayesian TLG formulations use MCMC based inference methods \cite{Ahmed2011, Hong:2011du, Wang2013, Ahmed:2012vh, Li2013}. They are simple to implement and an intuitive method for exploring an unknown density. On the other hand they tend to scale poorly with both data-set size and dimensionality \cite{wainwright2008graphical, Grimmer_2010}.

Variational inference (a type of EM-algorithm) has been shown to generate models of similar quality to MCMC methods several order of magnitudes faster \cite{wainwright2008graphical, Grimmer_2010}. No implementations of TLG to date use this form of inference. Variational methods are highly specific to the underlying model, and developing a new variational inference formulation is an involved task. Nevertheless they have the potential massively increase scalability of TLG models.

## Variational Inference

Developing the full update rules for the variational inference model is beyond the scope of this paper. What we have opted to do instead is attempt to reformulate approaches used for similar models. The work of Wang et al. \cite{Wang2011} and Bryant et al.\cite{Bryant2012} on variational inference is a good first step. They have developed a variational framework for a specific realisation of the HDP. It differs from the topic model underlying our TLG in a few ways (how hierarchy is represented, whether temporality is considered etc). However, it is an excellent proof-of-concept for applying VI methods to the timeline generation problem.

For an example of the optimisation update-rules, see **(Fig. 4)**. The complete procedure can be found in the original paper \cite{Bryant2012}.